@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Classes representing different kinds of astronomical position."""
 
-from numpy import array, cos, einsum, full, reshape, nan, nan_to_num
+from numpy import array, cos, einsum, full, reshape, nan, nan_to_num, zeros
 from . import framelib
 from .constants import ANGVEL, AU_M, C, ERAD, DAY_S, RAD2DEG, pi, tau
 from .descriptorlib import reify
@@ -55,24 +55,20 @@ def position_of_radec(ra_hours, dec_degrees, distance_au=_GIGAPARSEC_AU,
 
 def position_from_radec(ra_hours, dec_degrees, distance=1.0, epoch=None,
                         t=None, center=None, target=None):
-    """DEPRECATED version of ``position_of_radec()``.
-
-    Problems:
-
-    * The ``distance`` parameter specifies no unit, contrary to Skyfield
-      best practices.  I have no idea what I was thinking.
-
-    * The default ``distance`` is far too small, since most objects for
-      which users specify an RA and declination are out on the celestial
-      sphere.  The hope was that users would see the length 1.0 and
-      think, “ah, yes, that’s obviously a fake placeholder value.”  But
-      it’s more likely that users will not even check the distance, or
-      maybe not even realize that a distance is involved.
-
-    """
+    """DEPRECATED version of ``position_of_radec()``."""
     return position_of_radec(ra_hours, dec_degrees, distance, epoch,
                              t, center, target)
 
+class SSB(object):
+    """The Solar System Barycenter."""
+    @staticmethod
+    def at(t):
+        """Return the position of the Solar System Barycenter at time ``t``."""
+        shape = (3,)
+        if t.shape:
+            shape += t.shape
+        return Barycentric(zeros(shape), zeros(shape), t)
+
 class ICRF(object):
     """An |xyz| position and velocity oriented to the ICRF axes.
 
@@ -81,7 +77,7 @@ class ICRF(object):
     to within 0.02 arcseconds.  It also supersedes older equinox-based
     systems like B1900 and B1950.
 
-    Each instance of this class provides a ``.position`` vector and a
+    Each instance of this class provides a ``.xyz`` vector and a
     ``.velocity`` vector that specify |xyz| coordinates along the axes
     of the ICRF.  A specific time ``.t`` might be specified or might be
     ``None``.
@@ -97,7 +93,7 @@ class ICRF(object):
         self.t = t
         self.position = self.xyz = Distance(position_au)
         if velocity_au_per_d is None:
-            velocity_au_per_d = full(self.position.au.shape, nan)
+            velocity_au_per_d = full(self.xyz.au.shape, nan)
         self.velocity = Velocity(velocity_au_per_d)
         self.center = self._default_center if center is None else center
         self.target = target
@@ -173,7 +169,7 @@ class ICRF(object):
                 "you can only subtract two vectors"
                 " if they both start at the same center"
             )
-        p = self.position.au - body.position.au
+        p = self.xyz.au - body.xyz.au
         if self.velocity is None or body.velocity is None:
             v = None
         else:
@@ -182,7 +178,7 @@ class ICRF(object):
 
     def __getitem__(self, i):
         return type(self)(
-            self.position.au[:,i],
+            self.xyz.au[:,i],
             self.velocity.au_per_d[:,i],
             self.t[i],
             self.center,
@@ -191,7 +187,7 @@ class ICRF(object):
 
     def __neg__(self):
         return type(self)(
-            -self.position.au,
+            -self.xyz.au,
             -self.velocity.au_per_d,
             self.t,
             self.target,
@@ -211,7 +207,7 @@ class ICRF(object):
         1.41421 au
 
         """
-        return Distance(length_of(self.position.au))
+        return Distance(length_of(self.xyz.au))
 
     def speed(self):
         """Compute the magnitude of the velocity vector.
@@ -258,10 +254,8 @@ class ICRF(object):
         03h 22m 54.73s
         +18deg 33' 04.5"
 
-        To get J2000.0 coordinates, simply pass ``ts.J2000``.
-
         """
-        position_au = self.position.au
+        position_au = self.xyz.au
         if epoch is not None:
             if isinstance(epoch, Time):
                 pass
@@ -300,7 +294,7 @@ class ICRF(object):
 
         """
         R = framelib.itrs.rotation_at(self.t)
-        r = mxv(R, self.position.au)
+        r = mxv(R, self.xyz.au)
         au, dec, sublongtiude = to_spherical(r)
         lon = getattr(self.center, 'longitude', None)
         if lon is None:
@@ -359,8 +353,8 @@ class ICRF(object):
         3 values from 43deg 23' 23.1" to 42deg 49' 46.6"
 
         """
-        u = self.position.au
-        v = another_icrf.position.au
+        u = self.xyz.au
+        v = another_icrf.xyz.au
 
         # Allow an array of positions to be compared with a single other
         # position.
@@ -394,7 +388,7 @@ class ICRF(object):
                              ' a floating point Terrestrial Time (TT),'
                              ' or the string "date" for epoch-of-date')
 
-        vector = mxv(epoch.C, self.position.au)
+        vector = mxv(epoch.C, self.xyz.au)
         return Distance(vector)
 
     def cirs_radec(self, epoch):
@@ -440,7 +434,7 @@ class ICRF(object):
         `reference_frames`.
 
         """
-        return Distance(mxv(frame.rotation_at(self.t), self.position.au))
+        return Distance(mxv(frame.rotation_at(self.t), self.xyz.au))
 
     def frame_xyz_and_velocity(self, frame):
         """Return |xyz| position and velocity vectors in a reference frame.
@@ -452,7 +446,7 @@ class ICRF(object):
 
         """
         R = frame.rotation_at(self.t)
-        r, v = self.position.au, self.velocity.au_per_d
+        r, v = self.xyz.au, self.velocity.au_per_d
         r = mxv(R, r)
         v = mxv(R, v)
         at = getattr(frame, '_dRdt_times_RT_at', None)
@@ -462,7 +456,7 @@ class ICRF(object):
         return Distance(r), Velocity(v)
 
     def frame_latlon(self, frame):
-        """Return longitude, latitude, and distance in the given frame.
+        """Return latitude, longitude, and distance in the given frame.
 
         Returns a 3-element tuple giving the latitude and longitude as
         :class:`~skyfield.units.Angle` objects and the range to the
@@ -470,14 +464,14 @@ class ICRF(object):
         `reference_frames`.
 
         """
-        vector = mxv(frame.rotation_at(self.t), self.position.au)
+        vector = mxv(frame.rotation_at(self.t), self.xyz.au)
         d, lat, lon = to_spherical(vector)
         return (Angle(radians=lat, signed=True),
                 Angle(radians=lon),
                 Distance(d))
 
     def frame_latlon_and_rates(self, frame):
-        """Return a reference frame longitude, latitude, range, and rates.
+        """Return a reference frame latitude, longitude, range, and rates.
 
         Return a 6-element tuple of 3 coordinates and 3 rates-of-change
         for this position in the given reference ``frame``:
@@ -530,7 +524,7 @@ class ICRF(object):
                 .format(self.center)
             )
 
-        x, y, z = self.position.au
+        x, y, z = self.xyz.au
         return SkyCoord(frame=frame, representation_type='cartesian',
                         unit=au, x=x, y=y, z=z)
 
@@ -551,8 +545,8 @@ class ICRF(object):
         # TODO: should we have the body .observe() the Sun, to account
         # for light travel time?
         s = sun.at(self.t)
-        u = self.position.au
-        v = u - s.position.au + self.center_barycentric.position.au
+        u = self.xyz.au
+        v = u - s.xyz.au + self.center_barycentric.xyz.au
         return Angle(radians=angle_between(u, v))
 
     def fraction_illuminated(self, sun):
@@ -582,14 +576,14 @@ class ICRF(object):
 
         """
         if self.center == 399:
-            earth_m = - self.position.m
+            earth_m = - self.xyz.m
         else:
             gcrs_position = self._observer_gcrs_au
             if gcrs_position is None:
                 raise ValueError('cannot tell whether this position is sunlit')
-            earth_m = - self.position.m - gcrs_position * AU_M
+            earth_m = - self.xyz.m - gcrs_position * AU_M
 
-        sun_m = (ephemeris['sun'] - ephemeris['earth']).at(self.t).position.m
+        sun_m = (ephemeris['sun'] - ephemeris['earth']).at(self.t).xyz.m
         near, far = intersect_line_and_sphere(sun_m + earth_m, earth_m, ERAD)
         return nan_to_num(far) <= 0
 
@@ -606,7 +600,7 @@ class ICRF(object):
             raise ValueError('can only compute Earth occultation for'
                              ' positions observed from an Earth satellite')
         earth_m = - observer_gcrs_au * AU_M
-        vector_m = self.position.m
+        vector_m = self.xyz.m
         near, far = intersect_line_and_sphere(vector_m, earth_m, ERAD)
         length_m = length_of(vector_m)
         return (nan_to_num(far) > 0) & (nan_to_num(near) < length_m)
@@ -668,7 +662,7 @@ class Barycentric(ICRF):
     >>> mars.at(t)
     <Barycentric BCRS position and velocity at date t center=0 target=499>
 
-    This class’s ``.position`` and ``.velocity`` are |xyz| vectors in
+    This class’s ``.xyz`` and ``.velocity`` are |xyz| vectors in
     the Barycentric Celestial Reference System (BCRS), the modern
     replacement for J2000 coordinates measured from the Solar System
     Barycenter.
@@ -711,7 +705,7 @@ class Astrometric(ICRF):
     usually generated in Skyfield by calling the `Barycentric` method
     `observe()`, which performs the light-time correction.
 
-    Both the ``.position`` and ``.velocity`` are |xyz| vectors
+    Both the ``.xyz`` and ``.velocity`` are |xyz| vectors
     oriented along the axes of the ICRF, the modern replacement for the
     J2000 reference frame.
 
@@ -746,10 +740,10 @@ class Astrometric(ICRF):
 
         """
         t = self.t
-        target_au = self.position.au.copy()
+        target_au = self.xyz.au.copy()
 
         cb = self.center_barycentric
-        bcrs_position = cb.position.au
+        bcrs_position = cb.xyz.au
         bcrs_velocity = cb.velocity.au_per_d
         observer_gcrs_au = cb._observer_gcrs_au
 
@@ -806,7 +800,7 @@ class Apparent(ICRF):
     These positions are usually produced in Skyfield by calling the
     `apparent()` method of an `Astrometric` object.
 
-    Both the ``.position`` and ``.velocity`` are |xyz| vectors
+    Both the ``.xyz`` and ``.velocity`` are |xyz| vectors
     oriented along the axes of the ICRF, the modern replacement for the
     J2000 reference frame.  If the observer is at the geocenter, they
     are more specifically GCRS coordinates.  Two common coordinates that
@@ -830,7 +824,7 @@ class Geocentric(ICRF):
     same instant, without accounting for light-travel time or the effect
     of relativity on the light itself.
 
-    Its ``.position`` and ``.velocity`` vectors have |xyz| axes that
+    Its ``.xyz`` and ``.velocity`` vectors have |xyz| axes that
     are those of the Geocentric Celestial Reference System (GCRS), an
     inertial system that is an update to J2000 and that does not rotate
     with the Earth itself.
@@ -861,7 +855,7 @@ def _to_altaz(position, temperature_C, pressure_mbar):
         else:
             raise ValueError(_altaz_message)
 
-    position_au = mxv(R, position.position.au)
+    position_au = mxv(R, position.xyz.au)
     r_au, alt, az = to_spherical(position_au)
 
     if temperature_C is None:
@@ -888,7 +882,7 @@ _altaz_message = (
 
 class _Fake(ICRF):  # support for deprecated frame rotation methods above
     def __init__(self, original, epoch):
-        self.position = original.position
+        self.xyz = original.xyz
         if isinstance(epoch, Time):
             self.t = epoch
         elif isinstance(epoch, float):
